@@ -21,7 +21,7 @@
 #   This specific module is licensed under the Perl Artistic License.
 #
 #
-#   $Id: Utils.pm,v 1.9 2004/11/22 02:31:46 fredo Exp $
+#   $Id: Utils.pm,v 1.10 2004/12/16 00:30:53 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Basic::PDF::Utils;
@@ -54,7 +54,7 @@ use vars qw(@EXPORT @ISA);
 @ISA = qw(Exporter);
 @EXPORT = qw(PDFBool PDFArray PDFDict PDFLiteral PDFName PDFNull PDFNum PDFStr PDFStrHex PDFUtf
              asPDFBool asPDFName asPDFNum asPDFStr);
-# no warnings qw(uninitialized);
+no warnings qw[ deprecated recursion uninitialized ];
 
 
 =head2 PDFBool
