@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Content.pm,v 1.37 2005/06/17 18:53:04 fredo Exp $
+#   $Id: Content.pm,v 1.39 2005/10/01 22:10:57 fredo Exp $
 #
 #=======================================================================
 
@@ -47,7 +47,7 @@ BEGIN {
 
     @ISA = qw(PDF::API2::Basic::PDF::Dict);
     
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,'$Revision: 1.37 $' =~ /Revision: (\S+)\s/); # $Date: 2005/06/17 18:53:04 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.39 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/10/01 22:10:57 $
 
 }
 
@@ -2044,7 +2044,8 @@ sub textend {
 
 =item $width = $txt->textlabel $x, $y, $font, $size, $text, %options
 
-Applys text with options, but without teststart/end and optionally returns the width of the given text.
+Applys text with options, but without teststart/end 
+and optionally returns the width of the given text.
 
 B<Example:> 
 
@@ -2053,12 +2054,19 @@ B<Example:>
         -rotate => -30,
         -color => '#FF0000',
         -hspace => 120,
-        -center => 1,
+        -align => 'center',
+    );
+    $t->textlabel(500,500,$myfont,20,'Page Header',
+        -rotate => 30,
+        -color => '#0000FF',
+        -hspace => 80,
+        -align => 'right',
     );
     
 =cut
 
-sub textlabel {
+sub textlabel 
+{
     my ($self,$x,$y,$font,$size,$text,%opts,$wht) = @_;
     my %trans_opts=( -translate => [$x,$y] );
     my %text_state=();
@@ -2084,11 +2092,16 @@ sub textlabel {
     $self->wordspace($opts{-wordspace})     if($opts{-wordspace});
     $self->render($opts{-render})           if($opts{-render});
 
-    if($opts{-right} || $opts{-align}=~/^r/i) {
+    if($opts{-right} || $opts{-align}=~/^r/i) 
+    {
         $wht = $self->text_right($text,%opts);
-    } elsif($opts{-center} || $opts{-align}=~/^c/i) {
+    } 
+    elsif($opts{-center} || $opts{-align}=~/^c/i) 
+    {
         $wht = $self->text_center($text,%opts);
-    } else {
+    } 
+    else 
+    {
         $wht = $self->text($text,%opts);
     }
     
@@ -2150,6 +2163,12 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Content.pm,v $
+    Revision 1.39  2005/10/01 22:10:57  fredo
+    added more docs for textlabel
+
+    Revision 1.38  2005/06/17 19:43:46  fredo
+    fixed CPAN modulefile versioning (again)
+
     Revision 1.37  2005/06/17 18:53:04  fredo
     fixed CPAN modulefile versioning (dislikes cvs)
 
