@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: TrueType.pm,v 1.13 2005/09/12 16:53:23 fredo Exp $
+#   $Id: TrueType.pm,v 1.14 2005/10/01 22:30:16 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont::TrueType;
@@ -51,7 +51,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::CIDFont );
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.13 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/09/12 16:53:23 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.14 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/10/01 22:30:16 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -76,7 +76,7 @@ sub new {
     my ($ff,$data)=PDF::API2::Resource::CIDFont::TrueType::FontFile->new($pdf,$file,@opts);
 
     $class = ref $class if ref $class;
-    my $self=$class->SUPER::new($pdf,$data->{apiname}.pdfkey());
+    my $self=$class->SUPER::new($pdf,$data->{apiname}.pdfkey().'~'.time());
     $pdf->new_obj($self) if(defined($pdf) && !$self->is_obj($pdf));
 
     $self->{' data'}=$data;
@@ -89,7 +89,7 @@ sub new {
 
     $de->{'FontDescriptor'} = $des;
     $de->{'Subtype'} = PDFName($self->iscff ? 'CIDFontType0' : 'CIDFontType2');
-    $de->{'BaseFont'} = PDFName($self->fontname);
+    $de->{'BaseFont'} = PDFName(pdfkey().'+'.($self->fontname).'~'.time());
     $de->{'DW'} = PDFNum($self->missingwidth);
     $des->{$self->data->{iscff} ? 'FontFile3' : 'FontFile2'}=$ff;
 
@@ -212,6 +212,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: TrueType.pm,v $
+    Revision 1.14  2005/10/01 22:30:16  fredo
+    fixed font-naming race condition for multiple document updates
+
     Revision 1.13  2005/09/12 16:53:23  fredo
     added -isocmap option
 
