@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,14 +27,15 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: georgiabolditalic.pm,v 1.5 2004/06/15 09:14:53 fredo Exp $
+#   $Id: georgiabolditalic.pm,v 1.8 2005/09/12 16:56:21 fredo Exp $
 #
 #=======================================================================
+package PDF::API2::Resource::Font::CoreFont::georgiabolditalic;
 
-$fonts->{georgiabolditalic}= {
+$FONTDATA = {
     'fontname' => 'Georgia,BoldItalic',
     'type' => 'TrueType',
-    'apiname' => 'Ge3',
+    'apiname' => 'GeBoIt',
     'ascender' => '916',
     'capheight' => '692',
     'descender' => '-219',
@@ -894,6 +895,15 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: georgiabolditalic.pm,v $
+    Revision 1.8  2005/09/12 16:56:21  fredo
+    applied mod_perl patch by Paul Schilling <pfschill@sbcglobal.net>
+
+    Revision 1.7  2005/06/07 23:21:39  fredo
+    fontkey correction
+
+    Revision 1.6  2005/03/14 22:01:28  fredo
+    upd 2005
+
     Revision 1.5  2004/06/15 09:14:53  fredo
     removed cr+lf
 
