@@ -27,11 +27,12 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: trebuchet.pm,v 1.7 2005/06/07 23:21:40 fredo Exp $
+#   $Id: trebuchet.pm,v 1.8 2005/09/12 16:56:22 fredo Exp $
 #
 #=======================================================================
+package PDF::API2::Resource::Font::CoreFont::trebuchet;
 
-$fonts->{trebuchet}= {
+$FONTDATA = {
     'fontname' => 'TrebuchetMS',
     'type' => 'TrueType',
     'apiname' => 'Treb',
@@ -608,6 +609,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: trebuchet.pm,v $
+    Revision 1.8  2005/09/12 16:56:22  fredo
+    applied mod_perl patch by Paul Schilling <pfschill@sbcglobal.net>
+
     Revision 1.7  2005/06/07 23:21:40  fredo
     fontkey correction
 
