@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,14 +27,15 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: verdanaitalic.pm,v 1.5 2004/06/15 09:14:54 fredo Exp $
+#   $Id: verdanaitalic.pm,v 1.8 2005/09/12 16:56:22 fredo Exp $
 #
 #=======================================================================
+package PDF::API2::Resource::Font::CoreFont::verdanaitalic;
 
-$fonts->{verdanaitalic}= {
+$FONTDATA = {
     'fontname' => 'Verdana,Italic',
     'type' => 'TrueType',
-    'apiname' => 'Ve4',
+    'apiname' => 'VeIt',
     'ascender' => '1005',
     'capheight' => '727',
     'descender' => '-209',
@@ -878,6 +879,15 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: verdanaitalic.pm,v $
+    Revision 1.8  2005/09/12 16:56:22  fredo
+    applied mod_perl patch by Paul Schilling <pfschill@sbcglobal.net>
+
+    Revision 1.7  2005/06/07 23:21:40  fredo
+    fontkey correction
+
+    Revision 1.6  2005/03/14 22:01:30  fredo
+    upd 2005
+
     Revision 1.5  2004/06/15 09:14:54  fredo
     removed cr+lf
 
