@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Postscript.pm,v 1.8 2005/06/17 18:53:34 fredo Exp $
+#   $Id: Postscript.pm,v 1.10 2005/10/01 22:41:07 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::Font::Postscript;
@@ -48,7 +48,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::Font );
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,'$Revision: 1.8 $' =~ /Revision: (\S+)\s/); # $Date: 2005/06/17 18:53:34 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.10 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/10/01 22:41:07 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -75,12 +75,12 @@ sub new {
     }
 
     $class = ref $class if ref $class;
-    $self = $class->SUPER::new($pdf, $data->{apiname}.pdfkey());
+    $self = $class->SUPER::new($pdf, $data->{apiname}.pdfkey().'~'.time());
     $pdf->new_obj($self) unless($self->is_obj($pdf));
     $self->{' data'}=$data;
 
     $self->{'Subtype'} = PDFName("Type1");
-    $self->{'BaseFont'} = PDFName($self->fontname);
+    $self->{'BaseFont'} = PDFName(pdfkey().'+'.($self->fontname).'~'.time());
 
     if($opts{-pdfname}) {
         $self->name($opts{-pdfname});
@@ -516,6 +516,12 @@ __END__
 =head1 HISTORY
 
     $Log: Postscript.pm,v $
+    Revision 1.10  2005/10/01 22:41:07  fredo
+    fixed font-naming race condition for multiple document updates
+
+    Revision 1.9  2005/06/17 19:44:03  fredo
+    fixed CPAN modulefile versioning (again)
+
     Revision 1.8  2005/06/17 18:53:34  fredo
     fixed CPAN modulefile versioning (dislikes cvs)
 
